==> haskell-clientsession-0.9.1.2-102-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-9YntbCoFhxRDbgGM19SaYS
key: clientsession-0.9.1.2-9YntbCoFhxRDbgGM19SaYS
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
abi: d210f8d72e7ac6e7d0485a72c6307bbc
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
import-dirs: /usr/lib/ghc-8.6.5/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/clientsession-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-9YntbCoFhxRDbgGM19SaYS
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-11TO9fSEmuqDlOPx6IouNl
    bytestring-0.10.8.2 cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT
    cipher-aes-0.2.11-FEFaIecbSdD4SWRSjVxIKs
    cprng-aes-0.6.1-HrMMpvMTwly9yOGD2vVgxm
    crypto-api-0.13.3-BkUbrvVpNfiChPu2ZO0fOd
    crypto-random-0.0.9-FSRi3sZKB1WKoeGDHG0333 directory-1.3.3.0
    entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz
    skein-1.0.9.4-HoifDeMiO1j5KBiBw1zqFp
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.1.2-105-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-Idgv9hdIoSfJe2cibji5t6
key: clientsession-0.9.1.2-Idgv9hdIoSfJe2cibji5t6
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
abi: f28133b385bcdf614d6a788675943745
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
import-dirs: /usr/lib/ghc-8.6.5/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/clientsession-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-Idgv9hdIoSfJe2cibji5t6
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-Bm9gqw70QXoBbkNHszCarm
    bytestring-0.10.8.2 cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    cipher-aes-0.2.11-FEFaIecbSdD4SWRSjVxIKs
    cprng-aes-0.6.1-HrMMpvMTwly9yOGD2vVgxm
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V
    crypto-random-0.0.9-FSRi3sZKB1WKoeGDHG0333 directory-1.3.3.0
    entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz
    skein-1.0.9.4-CszzWfh6QCWEKzxEAVSxr8
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
